aboutsummaryrefslogtreecommitdiff
path: root/gdb/go32-nat.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/go32-nat.c')
-rw-r--r--gdb/go32-nat.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/gdb/go32-nat.c b/gdb/go32-nat.c
index ed54247..8f59426 100644
--- a/gdb/go32-nat.c
+++ b/gdb/go32-nat.c
@@ -85,7 +85,7 @@
#include <fcntl.h>
-#include "i386-nat.h"
+#include "x86-nat.h"
#include "inferior.h"
#include "infrun.h"
#include "gdbthread.h"
@@ -97,7 +97,7 @@
#include "buildsym.h"
#include "i387-tdep.h"
#include "i386-tdep.h"
-#include "nat/i386-cpuid.h"
+#include "nat/x86-cpuid.h"
#include "value.h"
#include "regcache.h"
#include "top.h"
@@ -735,7 +735,7 @@ go32_mourn_inferior (struct target_ops *ops)
be nice if GDB itself would take care to remove all breakpoints
at all times, but it doesn't, probably under an assumption that
the OS cleans up when the debuggee exits. */
- i386_cleanup_dregs ();
+ x86_cleanup_dregs ();
ptid = inferior_ptid;
inferior_ptid = null_ptid;
@@ -1083,12 +1083,12 @@ go32_sysinfo (char *arg, int from_tty)
{
/* CPUID with EAX = 0 returns the Vendor ID. */
#if 0
/* Ideally we would use i386_cpuid(), but it needs someone to run
native tests first to make sure things actually work. They should.
http://sourceware.org/ml/gdb-patches/2013-05/msg00164.html */
unsigned int eax, ebx, ecx, edx;
- if (i386_cpuid (0, &eax, &ebx, &ecx, &edx))
+ if (x86_cpuid (0, &eax, &ebx, &ecx, &edx))
{
cpuid_max = eax;
memcpy (&vendor[0], &ebx, 4);
@@ -1141,7 +1141,7 @@ go32_sysinfo (char *arg, int from_tty)
#if 0
/* See comment above about cpuid usage. */
- i386_cpuid (1, &cpuid_eax, &cpuid_ebx, NULL, &cpuid_edx);
+ x86_cpuid (1, &cpuid_eax, &cpuid_ebx, NULL, &cpuid_edx);
#else
__asm__ __volatile__ ("movl $1, %%eax;"
"cpuid;"
@@ -2062,14 +2062,14 @@ _initialize_go32_nat (void)
{
struct target_ops *t = go32_target ();
- i386_dr_low.set_control = go32_set_dr7;
- i386_dr_low.set_addr = go32_set_dr;
- i386_dr_low.get_status = go32_get_dr6;
- i386_dr_low.get_control = go32_get_dr7;
- i386_dr_low.get_addr = go32_get_dr;
- i386_set_debug_register_length (4);
+ x86_dr_low.set_control = go32_set_dr7;
+ x86_dr_low.set_addr = go32_set_dr;
+ x86_dr_low.get_status = go32_get_dr6;
+ x86_dr_low.get_control = go32_get_dr7;
+ x86_dr_low.get_addr = go32_get_dr;
+ x86_set_debug_register_length (4);
- i386_use_watchpoints (t);
+ x86_use_watchpoints (t);
add_target (t);
/* Initialize child's cwd as empty to be initialized when starting
@@ -1083,12 +1083,12 @@ go32_sysinfo (char *arg, int from_tty)
/* CPUID with EAX = 0 returns the Vendor ID. */
#if 0
- /* Ideally we would use i386_cpuid(), but it needs someone to run
+ /* Ideally we would use x86_cpuid(), but it needs someone to run
native tests first to make sure things actually work. They should.
http://sourceware.org/ml/gdb-patches/2013-05/msg00164.html */